@@ -1,4 +1,3 @@
-# JSON helper functions
 from django.http import HttpResponse
 
 try:
@@ -6,7 +5,16 @@ try:
 except ImportError:
     import json
 
+# JSON helper functions
+
 def JSONResponse(data, dump=True):
+    try:
+        data['errors']
+    except KeyError:
+        data['success'] = True
+    except TypeError:
+        pass
+
     return HttpResponse(
         json.dumps(data) if dump else data,
         mimetype='application/json',
